d.to.cles: Conversion from Cohen's d to Common Language Effect Size
Description
Helper function to convert Cohen's d to common language effect size (or vice
versa). The result is the probability of superiority for independent
samples. It can be interpreted as the probability that a randomly selected
observation from Group 1 exceeds a randomly selected observation from Group
2. The rationale is the same for paired-samples and one-sample designs, but
the interpretation differs: For paired samples, it can be interpreted as the
probability that the difference score (i.e., the score under Condition 1
minus the score under Condition 2) is greater than zero for a randomly
selected individual. For a one-sample design, it can be interpreted as the
probability that a randomly selected observation is greater than the
reference value (e.g., 0).
character; one of the "independent", "paired", or
"one.sample". The default is "independent".
verbose
1 by default (returns test, hypotheses, and results),
if 2 a more detailed output is given (plus key
parameters and definitions), if 0 no output is printed
on the console.