Learn R Programming

pwrss (version 1.3.1)

power.binom.test: Power Analysis for the Generic Binomial Test

Description

Calculates power or find Probability (Non-Centrality) for the generic binomial test with (optional) Type 1 and Type 2 error plots.

Usage

power.binom.test(
  power = NULL,
  size = NULL,
  prob = NULL,
  null.prob = 0.5,
  req.sign = "+",
  alpha = 0.05,
  alternative = c("two.sided", "one.sided", "two.one.sided"),
  plot = TRUE,
  verbose = 1,
  utf = FALSE
)

Value

power

statistical power \((1 - \beta)\).

size

number of trials (zero or more).

prob

probability of success on each trial under alternative.

null.prob

probability of success on each trial under null.

alpha

type 1 error rate.

alternative

direction or type of the hypothesis test.

binom.alpha

critical value(s).

Arguments

power

statistical power \((1 - \beta)\); either power, size, or prob needs to be NULL (and is then estimated).

size

number of trials (zero or more); either power, size, or prob needs to be NULL (and is then estimated).

prob

probability of success on each trial under alternative; either power, size or prob needs to be NULL (and is then estimated).

null.prob

probability of success on each trial under null.

req.sign

whether 'prob' is expected to be greater '+1', less than '-1', or within '0' the null.prob' bounds.

alpha

type 1 error rate, defined as the probability of incorrectly rejecting a true null hypothesis, denoted as \(\alpha\).

alternative

character; the direction or type of the hypothesis test: "two.sided", "one.sided", or "two.one.sided". For non-inferiority or superiority tests, add or subtract the margin from the null hypothesis value and use alternative = "one.sided".

plot

logical; FALSE switches off Type 1 and Type 2 error plot. TRUE by default.

verbose

1 by default (returns test, hypotheses, and results), if 2 a more detailed output is given (plus key parameters and definitions), if 0 no output is printed on the console.

utf

logical; whether the output should show Unicode characters (if encoding allows for it). FALSE by default.

Examples

Run this code
# one-sided
power.binom.test(size = 200, prob = 0.6, null.prob = 0.5, alpha = 0.05,
                 alternative = "one.sided")
power.binom.test(power = 0.80, size = 200, req.sign = "+", null.prob = 0.5,
                 alpha = 0.05, alternative = "one.sided")

# two-sided
power.binom.test(size = 200, prob = 0.4, null.prob = 0.5, alpha = 0.05,
                 alternative = "two.sided")
power.binom.test(power = 0.80, size = 200, req.sign = "+", null.prob = 0.5,
                 alpha = 0.05, alternative = "two.sided")

# equivalence
power.binom.test(size = 200, prob = 0.5, null.prob = c(0.4, 0.6),
                 alpha = 0.05, alternative = "two.one.sided")
power.binom.test(power = 0.80, size = 200, req.sign = "0",
                 null.prob = c(0.4, 0.6), alpha = 0.05,
                 alternative = "two.one.sided")

Run the code above in your browser using DataLab