Learn R Programming

pwrss (version 1.3.1)

power.chisq.test: Statistical Power for the Generic Chi-Square Test

Description

Determines power, the non-centrality parameter (NCP) for the generic chi-square test with (optional) Type 1 and Type 2 error plots.

Usage

power.chisq.test(
  power = NULL,
  ncp = NULL,
  null.ncp = 0,
  df = NULL,
  alpha = 0.05,
  plot = TRUE,
  verbose = 1,
  utf = FALSE
)

Value

power

statistical power \((1-\beta)\).

ncp

non-centrality parameter under alternative.

null.ncp

non-centrality parameter under null.

df

degrees of freedom.

alpha

type 1 error rate (user-specified).

chisq.alpha

critical value.

Arguments

power

statistical power \((1 - \beta)\); either power, ncp or df needs to be NULL (and is then estimated).

ncp

non-centrality parameter for the alternative; either power, ncp or df needs to be NULL (and is then estimated).

null.ncp

non-centrality parameter for the null.

df

integer; degrees of freedom, e.g., for the test of independence df = (nrow - 1) * (ncol - 1); either power, ncp or df needs to be NULL (and is then estimated).

alpha

type 1 error rate, defined as the probability of incorrectly rejecting a true null hypothesis, denoted as \(\alpha\).

plot

logical; FALSE switches off Type 1 and Type 2 error plot. TRUE by default.

verbose

1 by default (returns test, hypotheses, and results), if 2 a more detailed output is given (plus key parameters and definitions), if 0 no output is printed on the console.

utf

logical; whether the output should show Unicode characters (if encoding allows for it). FALSE by default.

Examples

Run this code
# power is defined as the probability of observing a test statistics greater
# than the critical value
power.chisq.test(ncp = 20, df = 100, alpha = 0.05)
power.chisq.test(power = 0.80, df = 100, alpha = 0.05)
power.chisq.test(power = 0.80, ncp = 20, alpha = 0.05)

Run the code above in your browser using DataLab