Helper function to convert probability difference to Cohen's h (and vice versa).
Arguments
- prob1
Probability of success in the first group, or under the alternative hypothesis in the one-sample case).
- prob2
Probability of success in the second group, or under the null hypothesis in the one-sample case).
- verbose
1by default (returns test, hypotheses, and results), if2a more detailed output is given (plus key parameters and definitions), if0no output is printed on the console.- h
Cohen's h effect size.